const path = require("path");

module.exports = {
  rulesDirectory: [
    path.join(path.dirname(require.resolve('codelyzer')), './'),
    path.join(path.dirname(require.resolve('vrsource-tslint-rules')), 'rules'),
    path.join(path.dirname(require.resolve('tslint-eslint-rules')), 'dist/rules')
  ],
  rules: {
    "align": [
      true,
      "arguments",
      "elements",
      "members",
      "parameters",
      "statements"
    ],
    "array-type": [
      true,
      "array"
    ],
    "arrow-parens": [
      true,
      "ban-single-arg-parens"
    ],
    "arrow-return-shorthand": true,
    "await-promise": true,
    "binary-expression-operand-order": true,
    "callable-types": true,
    "comment-format": [
      true,
      "check-space"
    ],
    "conditional-expression-parens": false,
    "curly": true,
    "encoding": true,
    "eofline": true,
    "ext-variable-name": [
      true,
      ["class", "pascal"],
      ["interface", "pascal", { "regex": "^I.*$" }],
      ["parameter", "camel"],
      ["property", "static", "camel"],
      ["property", "private", "camel", "require-leading-underscore"],
      ["property", "protected", "camel", "require-leading-underscore"],
      ["property", "camel"],
      ["method", "camel"],
      ["function", "camel"]
    ],
    "forin": true,
    "import-blacklist": [true, "rxjs"],
    "import-spacing": true,
    "ter-indent": [
      true,
      4,
      {
        "SwitchCase": 1
      }
    ],
    "interface-over-type-literal": true,
    "jsdoc-format": true,
    "label-position": true,
    "literal-spacing": [
      true,
      {
        "array": ["never"],
        "object": ["always"],
        "import": ["always"]
      }
    ],
    "max-line-length": [
      true,
      140
    ],
    "member-access": true,
    "member-ordering": [
      true,
      {
        "order": [
          "static-field",
          "instance-field",
          "constructor",
          "static-method",
          "instance-method"
        ]
      }
    ],
    "new-parens": true,
    "no-angle-bracket-type-assertion": true,
    "no-arg": true,
    "no-bitwise": true,
    "no-boolean-literal-compare": true,
    "no-console": [
      true,
      "debug",
      "info",
      "time",
      "timeEnd",
      "trace"
    ],
    "no-conditional-assignment": true,
    "no-construct": true,
    "no-debugger": true,
    "no-duplicate-imports": true,
    "no-duplicate-super": true,
    "no-duplicate-variable": true,
    "no-empty": false,
    "no-empty-interface": true,
    "no-eval": true,
    // "no-increment-decrement": true,
    "no-inferrable-types": [
      true,
      "ignore-params",
      "ignore-properties"
    ],
    "no-inferred-empty-object-type": true,
    "no-invalid-template-strings": true,
    "no-invalid-this": true,
    "no-non-null-assertion": false,
    "no-null-keyword": true,
    "no-object-literal-type-assertion": true,
    "no-param-reassign": true,
    "no-reference": true,
    "no-shadowed-variable": true,
    "no-sparse-arrays": true,
    "no-string-literal": false,
    "no-string-throw": true,
    "no-switch-case-fall-through": true,
    "no-trailing-whitespace": [
      true,
      "ignore-template-strings"
    ],
    "no-unused-expression": true,
    "no-unused-variable": false,
    "no-use-before-declare": false,
    "no-var-keyword": true,
    "no-var-requires": true,
    "number-literal-format": true,
    "object-literal-sort-keys": false,
    "one-line": [
      true,
      "check-catch",
      "check-finally",
      "check-else",
      "check-open-brace",
      "check-whitespace"
    ],
    "one-variable-per-declaration": [
      true,
      "ignore-for-loop"
    ],
    "only-arrow-functions": [
      true,
      "allow-declarations"
    ],
    "prefer-conditional-expression": false,
    "prefer-const": true,
    "prefer-literal": [
      true,
      "object",
      "function",
      "array"
    ],
    "prefer-object-spread": true,
    "prefer-template": true,
    "promise-function-async": true,
    "quotemark": [
      true,
      "single",
      "avoid-escape"
    ],
    "radix": true,
    "restrict-plus-operands": true,
    "semicolon": [
      true,
      "always"
    ],
    "space-before-function-paren": [
      true,
      {
        "anonymous": "never",
        "named": "never",
        "asyncArrow": "always",
        "method": "never",
        "constructor": "never"
      }
    ],
    "trailing-comma": [
      true,
      {
        "multiline": "never",
        "singleline": "never"
      }
    ],
    "triple-equals": [
      true,
      "allow-undefined-check"
    ],
    "type-literal-delimiter": true,
    "typedef": [
      true,
      "call-signature",
      "parameter",
      "member-variable-declaration"
    ],
    "typedef-whitespace": [
      true,
      {
        "call-signature": "nospace",
        "index-signature": "nospace",
        "parameter": "nospace",
        "property-declaration": "nospace",
        "variable-declaration": "nospace"
      },
      {
        "call-signature": "nospace",
        "index-signature": "nospace",
        "parameter": "nospace",
        "property-declaration": "nospace",
        "variable-declaration": "nospace"
      }
    ],
    "typeof-compare": true,
    "unified-signatures": true,
    "use-default-type-parameter": true,
    "variable-name": [
      true,
      "ban-keywords",
      "check-format",
      "allow-pascal-case",
      "allow-leading-underscore"
    ],
    "whitespace": [
      true,
      "check-branch",
      "check-decl",
      "check-operator",
      "check-module",
      "check-separator"
    ],

    "directive-selector": false,
    "component-selector": false,
    "use-input-property-decorator": true,
    "use-output-property-decorator": true,
    "use-host-property-decorator": false,
    "no-input-rename": false,
    "no-output-rename": false,
    "use-life-cycle-interface": true,
    "use-pipe-transform-interface": true,
    "component-class-suffix": false,
    "directive-class-suffix": false,
    "no-access-missing-member": false,
    "templates-use-public": true,
    "invoke-injectable": true
  }
};
